      SUBROUTINE STAF2(CFC,SC,LSR,LM,ALP) 
C 
C     * JUL 14/92 - E. CHAN (ADD REAL*8 DECLARATIONS)
C     * APR  1/80 - J.D.HENDERSON 
C     * CONVERTS SPHERICAL HARMONICS IN SC TO FOURIER COEFF IN CFC
C     * AT ONE PARTICULAR LATITUDE. 
C     * SPECTRAL HARMONICS MUST BE GLOBAL.
C 
C     * LSR(1,M)=START OF ROW M OF SC 
C     * LSR(2,M)=START OF ROW M OF ALP
C                LONGEST ROW LENGTH PERMITTED IS 60.
C     * LM = NUMBER OF ROWS IN SC,ALP ARRAYS. 
C     * ALP = ASSOCIATED LEGENDRE POLYNOMIALS FOR GIVEN LATITUDE. 
C 
C     * LEVEL 2,SC,CFC,ALP
      IMPLICIT REAL (A-H,O-Z),
     +INTEGER (I-N)
      COMPLEX SC(1),CFC(1)
      REAL*8 ALP(1) 
      INTEGER LSR(2,1)
C 
      DO 220 M=1,LM 
      NA=LSR(2,M)-1 
      NL=LSR(1,M) 
      NR=LSR(1,M+1)-1 
      FCR=0.E0
      FCI=0.E0
      DO 210 N=NL,NR
      NA=NA+1 
      FCR=FCR+ALP(NA)* REAL(SC(N))
  210 FCI=FCI+ALP(NA)* IMAG(SC(N))
C 
  220 CFC(M)=CMPLX(FCR,FCI) 
C 
      RETURN
      END 
